package RPM::Source::Transformation::Provider::Name2Spec::SRPMorHasherTar;

use strict;
use warnings;
use Cwd qw/abs_path cwd/;

use Source::Package::RPM::ALTNoEpoch;
use Source::Repository::RPM::ALTLinuxSrcList 0.001;
use RPM::Source::Transformation::RPMEditorProvider 0.001;
use RPM::Source::Transformation::Component;
our @ISA=qw/RPM::Source::Transformation::Component/;
$RPM::Source::TransformContainer::Name2SpecProvider=__PACKAGE__;

$Source::Repository::RPM::ALTLinuxSrcList::allow_hashertar=1;
$Source::Repository::RPM::ALTLinuxSrcList::package_class='Source::Package::RPM::ALTNoEpoch';

our $verbose=0;
my $repository_obj;
my @srpmdir;

sub print_longopt {
    print "  Name2Spec SRPM/HasherTar resolver input options:
	--input-srpm-dir|indir /path/to/src.rpms
";
}
our @LONGOPT=(
    "indir|input-srpm-dir|srpmdir=s"   => \@srpmdir,
    );

sub process_options {
    my $class=shift;
    if (not @srpmdir) {
	print STDERR "--input-srpm-dir <path> is required\n";
	$class->usage();
	exit 1;
    }
    my @inpath=map {abs_path($_)} @srpmdir;
    $repository_obj=Source::Repository::RPM::ALTLinuxSrcList->create_repo_chain_from_cli(-path=>\@inpath);
}

sub name2spec {
    my (undef,$name,$converter_opt)=@_;
    my $pkg=$repository_obj->name2pkg($name);
    die "Provider::Name2Spec: source rpm file not found for $name.\n" unless $pkg;
    my $hashertar;
    my $infile=$pkg->file;
    if ($infile=~m!(?:^|/)((?:[^/]+)-(?:[^/-]+)-(?:[^/-]+))\.(src\.rpm|tar)$!) {
        $converter_opt->{-name2spec_provided_nvr}=$1;
	$hashertar=1 if $2 eq 'tar';
    }
    if ($hashertar) {
	print STDERR "DEBUG: name2spec: HASHERTAR=",$infile,"\n" if $verbose;
	return $RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec([HASHERTAR=>$infile]);
    } else {
	print STDERR "DEBUG: name2spec: SOURCERPM=",$infile,"\n" if $verbose;
	return $RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec([SOURCERPM=>$infile]);
    }
}

1;
